class CodeConstant:
    LABEL_CODE_ELEMENT = "code_element"


class DomainConstant:
    LABEL_DOMAIN_TERM = "domain term"
    PRIMARY_PROPERTY_NAME = "term_name"


class OperationConstance:
    LABEL_OPERATION = "operation"
    PRIMARY_PROPERTY_NAME = "operation_name"


class PropertyConstant:
    COMMENT = "comment"
    INSIDE_COMMENT = "inside_comment"
    STRING_LITERAL_EXPR = "string_literal_expr"
    DESCRIPTION = "short_description"
    ALIAS = "alias"
    LEMMA = "lemma"
